==> zio-aws-ec2_2.12-5.17.130.5-sources.jar: zio/aws/ec2/model/DeleteLocalGatewayRouteTableVpcAssociationResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteLocalGatewayRouteTableVpcAssociationResponse(
    localGatewayRouteTableVpcAssociation: Option[
      zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse = {
    import DeleteLocalGatewayRouteTableVpcAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
      .builder()
      .optionallyWith(
        localGatewayRouteTableVpcAssociation.map(value => value.buildAwsValue())
      )(_.localGatewayRouteTableVpcAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse.ReadOnly =
    zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
      .wrap(buildAwsValue())
}
object DeleteLocalGatewayRouteTableVpcAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse =
      zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse(
        localGatewayRouteTableVpcAssociation.map(value => value.asEditable)
      )
    def localGatewayRouteTableVpcAssociation: Option[
      zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation.ReadOnly
    ]
    def getLocalGatewayRouteTableVpcAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "localGatewayRouteTableVpcAssociation",
      localGatewayRouteTableVpcAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
  ) extends zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse.ReadOnly {
    override val localGatewayRouteTableVpcAssociation: Option[
      zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation.ReadOnly
    ] = scala
      .Option(impl.localGatewayRouteTableVpcAssociation())
      .map(value =>
        zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
  ): zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-6.20.58.3-sources.jar: zio/aws/ec2/model/DeleteLocalGatewayRouteTableVpcAssociationResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteLocalGatewayRouteTableVpcAssociationResponse(
    localGatewayRouteTableVpcAssociation: Optional[
      zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse = {
    import DeleteLocalGatewayRouteTableVpcAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
      .builder()
      .optionallyWith(
        localGatewayRouteTableVpcAssociation.map(value => value.buildAwsValue())
      )(_.localGatewayRouteTableVpcAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse.ReadOnly =
    zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
      .wrap(buildAwsValue())
}
object DeleteLocalGatewayRouteTableVpcAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse =
      zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse(
        localGatewayRouteTableVpcAssociation.map(value => value.asEditable)
      )
    def localGatewayRouteTableVpcAssociation: Optional[
      zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation.ReadOnly
    ]
    def getLocalGatewayRouteTableVpcAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "localGatewayRouteTableVpcAssociation",
      localGatewayRouteTableVpcAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
  ) extends zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse.ReadOnly {
    override val localGatewayRouteTableVpcAssociation: Optional[
      zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.localGatewayRouteTableVpcAssociation())
      .map(value =>
        zio.aws.ec2.model.LocalGatewayRouteTableVpcAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse
  ): zio.aws.ec2.model.DeleteLocalGatewayRouteTableVpcAssociationResponse.ReadOnly =
    new Wrapper(impl)
}
